@@ -38,6 +38,7 @@
 #include "gtr-msg.h"
 #include "gtr-enum-types.h"
 #include "gtr-profile.h"
+#include "gtr-profile-manager.h"
 #include "gtr-utils.h"
 #include "gtr-message-container.h"
 #include "gtr-preferences-dialog.h"
@@ -97,8 +98,8 @@ typedef struct
 
   GtrPoState state;
 
-  /* Damned Lies(DL) teams are stored here */
-  gchar *dl_team;
+  /* Damned Lies(DL) lang are stored here */
+  gchar *dl_lang;
 
   /* DL modules */
   gchar *dl_module;
@@ -129,6 +130,14 @@ enum
   PROP_STATE
 };
 
+enum
+{
+  FILE_INCONSISTENT_WITH_PROFILE,
+  NO_OF_SIGNALS
+};
+
+static guint signals[NO_OF_SIGNALS];
+
 static gchar *message_error = NULL;
 
 static void
@@ -221,7 +230,7 @@ gtr_po_init (GtrPo * po)
   priv->po_contains_obsolete_entries = FALSE;
   priv->location = NULL;
   priv->gettext_po_file = NULL;
-  priv->dl_team = NULL;
+  priv->dl_lang = NULL;
   priv->dl_module = NULL;
   priv->dl_branch = NULL;
   priv->dl_domain = NULL;
@@ -241,8 +250,8 @@ gtr_po_finalize (GObject * object)
   if (priv->gettext_po_file)
     po_file_free (priv->gettext_po_file);
 
-  if (priv->dl_team)
-    g_free (priv->dl_team);
+  if (priv->dl_lang)
+    g_free (priv->dl_lang);
   if (priv->dl_module)
     g_free (priv->dl_module);
   if (priv->dl_branch)
@@ -331,6 +340,14 @@ gtr_po_class_init (GtrPoClass * klass)
                                                       GTR_TYPE_PO_STATE,
                                                       GTR_PO_STATE_SAVED,
                                                       G_PARAM_READABLE));
+  /* Signals */
+  signals[FILE_INCONSISTENT_WITH_PROFILE] =
+    g_signal_new ("file-is-inconsistent-with-profile",
+                  G_OBJECT_CLASS_TYPE (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0, NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE, 0);
 }
 
 /*
@@ -965,21 +982,30 @@ gtr_po_set_state (GtrPo * po, GtrPoState state)
   g_object_notify (G_OBJECT (po), "state");
 }
 
-void gtr_po_set_dl_info (GtrPo * po, gchar * team, gchar * module_name,
+void gtr_po_set_dl_info (GtrPo * po, gchar * lang, gchar * module_name,
                          gchar * branch, gchar * domain, gchar * module_state)
 {
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
-  priv->dl_team = g_strdup (team);
+  priv->dl_lang = g_strdup (lang);
   priv->dl_module = g_strdup (module_name);
   priv->dl_branch = g_strdup (branch);
   priv->dl_domain = g_strdup (domain);
   priv->dl_state = g_strdup (module_state);
 
-  gtr_header_set_field (priv->header, "X-DL-Team", team);
-  gtr_header_set_field (priv->header, "X-DL-Module", module_name);
-  gtr_header_set_field (priv->header, "X-DL-Branch", branch);
-  gtr_header_set_field (priv->header, "X-DL-Domain", domain);
-  gtr_header_set_field (priv->header, "X-DL-State", module_state);
+  if (lang)
+    gtr_header_set_field (priv->header, "X-DL-Lang", lang);
+
+  if (module_name)
+    gtr_header_set_field (priv->header, "X-DL-Module", module_name);
+
+  if (branch)
+    gtr_header_set_field (priv->header, "X-DL-Branch", branch);
+
+  if (domain)
+    gtr_header_set_field (priv->header, "X-DL-Domain", domain);
+
+  if (module_state)
+    gtr_header_set_field (priv->header, "X-DL-State", module_state);
 }
 /*
  * FIXME: We are not using this func.
@@ -1401,11 +1427,40 @@ gtr_po_check_po_file (GtrPo * po)
   return message_error;
 }
 
+/**
+ * gtr_po_consistent_with_profile
+ * @po: a #GtrPo
+ *
+ * Tests whether the po file is consistent or not with profile values
+ * Returns: If the po file is not consistent with profile then it returns 0 .
+ **/
+gboolean
+gtr_po_consistent_with_profile (GtrPo * po)
+{
+  GtrProfileManager *prof_manager;
+  GtrProfile *profile;
+  gint po_header_nplurals;
+  gint profile_nplurals = -1;
+
+  GtrHeader *header = gtr_po_get_header (po);
+  po_header_nplurals = gtr_header_get_nplurals (header);
+
+  prof_manager = gtr_profile_manager_get_default ();
+  profile = gtr_profile_manager_get_active_profile (prof_manager);
+  profile_nplurals = parse_nplurals_header (
+    gtr_profile_get_plural_forms (profile)
+  );
+
+  g_object_unref (prof_manager);
+
+  return profile_nplurals == po_header_nplurals;
+}
+
 const gchar *
-gtr_po_get_dl_team (GtrPo *po)
+gtr_po_get_dl_lang (GtrPo *po)
 {
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
-  return priv->dl_team;
+  return priv->dl_lang;
 }
 
 const gchar *
@@ -1442,3 +1497,9 @@ gtr_po_can_dl_upload (GtrPo *po)
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
   return g_strcmp0 (priv->dl_state, "Translating") == 0;
 }
+
+void
+gtr_po_emit_file_not_consistent (GtrPo *po)
+{
+  g_signal_emit (G_OBJECT(po), signals[FILE_INCONSISTENT_WITH_PROFILE], 0);
+}
