@@ -86,10 +86,10 @@ GQuark gtr_po_error_quark (void);
 
      void gtr_po_set_state (GtrPo * po, GtrPoState state);
 
-     void gtr_po_set_dl_info (GtrPo * po, gchar * team, gchar * module_name,
+     void gtr_po_set_dl_info (GtrPo * po, gchar * lang, gchar * module_name,
                               gchar * branch, gchar * domain, gchar * module_state);
 
-     const gchar *gtr_po_get_dl_team (GtrPo * po);
+     const gchar *gtr_po_get_dl_lang (GtrPo * po);
 
      const gchar *gtr_po_get_dl_module (GtrPo * po);
 
@@ -152,7 +152,11 @@ gtr_po_get_message_position (GtrPo * po);
 
      gchar *gtr_po_check_po_file (GtrPo * po);
 
+void
+gtr_po_emit_file_not_consistent (GtrPo * po);
 
+gboolean
+gtr_po_consistent_with_profile (GtrPo * po);
 /* Unexported funcs */
      void
        _gtr_po_increase_decrease_translated (GtrPo * po, gboolean increase);
