@@ -28,6 +28,7 @@
  *   Thomas Ziehmer <thomas@kabalak.net>
  */
 
+#include "gtr-profile.h"
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -35,7 +36,6 @@
 #include "gtr-application.h"
 #include "gtr-context.h"
 #include "gtr-io-error-info-bar.h"
-#include "gtr-message-table.h"
 #include "gtr-msg.h"
 #include "gtr-tab-activatable.h"
 #include "gtr-tab.h"
@@ -48,6 +48,7 @@
 #include "gtr-progress.h"
 #include "gtr-actions.h"
 #include "gtr-utils.h"
+#include "gtr-profile-manager.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -66,7 +67,7 @@ typedef struct
   GSettings *editor_settings;
   GSettings *state_settings;
 
-  GtkWidget *progress_eventbox;
+  GtkGesture *progress_gesture_click;
   GtkWidget *progress_box;
   GtkWidget *progress_revealer;
   GtkWidget *progress_percentage;
@@ -80,19 +81,15 @@ typedef struct
   GtrPo *po;
 
   GtkWidget *dock;
+  GtkWidget *window;
 
-  /*Vertical and Horizontal Panes */
-  GtkPaned *hbox;
-  GtkPaned *vertical_box;
-  gint context_position;
-  gint content_position;
+  /* Flap state */
+  AdwFlap *hbox;
+  gboolean flap_state;
 
   GtkWidget *message_table;
   GtkWidget *context;
 
-  /*Info bar */
-  GtkWidget *infobar;
-
   /*Original text */
   GtkWidget *text_msgid;
   GtkWidget *text_plural_scroll;
@@ -122,10 +119,22 @@ typedef struct
   guint dispose_has_run : 1;
 
   /*Search Bar*/
-  GtkOverlay     *overlay;
-  GtkRevealer    *search_revealer;
-  GtrSearchBar   *search_bar;
-  GtkSearchEntry *search;
+  GtkSearchBar   *search_bar;
+  GtrSearchBar   *gtr_search_bar;
+
+  /* notebook code */
+  GtkWidget *titlebar;
+  GtkWidget *save;
+  GtkWidget *sort_id;
+  GtkWidget *sort_status;
+  GtkWidget *sort_msgid;
+  GtkWidget *sort_translated;
+  GtkWidget *order_menu_popover;
+  GtkWidget *search_toggle;
+  GtkWidget *upload;
+
+  GtkWidget *undo;
+  GtkWidget *redo;
 
 } GtrTabPrivate;
 
@@ -137,6 +146,7 @@ enum
   MESSAGE_CHANGED,
   MESSAGE_EDITION_FINISHED,
   SELECTION_CHANGED,
+  SEARCHBAR_TOGGLED,
   LAST_SIGNAL
 };
 
@@ -161,10 +171,7 @@ gtr_page_stop_search (GtrTab *tab,
   GtrTabPrivate *priv;
 
   priv = gtr_tab_get_instance_private (tab);
-  g_assert (GTR_IS_TAB (tab));
-  g_assert (GTR_IS_SEARCH_BAR (priv->search_bar));
-
-  gtk_revealer_set_reveal_child (priv->search_revealer, FALSE);
+  gtk_search_bar_set_search_mode (priv->search_bar, FALSE);
 
 }
 
@@ -177,7 +184,7 @@ gtr_tab_focus_search_bar (GtrTab *tab)
   g_assert (GTR_IS_TAB (tab));
   priv = gtr_tab_get_instance_private (tab);
 
-  entry = (GtkEntry *) gtr_search_bar_get_search (priv->search_bar);
+  entry = (GtkEntry *) gtr_search_bar_get_search (priv->gtr_search_bar);
 
   gtk_entry_grab_focus_without_selecting (entry);
 }
@@ -187,10 +194,10 @@ gtr_tab_show_hide_search_bar (GtrTab *tab, gboolean show)
 {
   GtrTabPrivate *priv;
 
-  g_assert (GTR_IS_TAB (tab));
   priv = gtr_tab_get_instance_private (tab);
-
-  gtk_revealer_set_reveal_child (priv->search_revealer, show);
+  gtk_search_bar_set_search_mode (priv->search_bar, show);
+  if (show)
+    gtr_tab_focus_search_bar (tab);
 }
 
 void
@@ -201,7 +208,7 @@ gtr_tab_find_set_replace (GtrTab   *tab,
 
   g_assert (GTR_IS_TAB (tab));
   priv = gtr_tab_get_instance_private (tab);
-  gtr_search_bar_set_replace_mode (priv->search_bar, replace);
+  gtr_search_bar_set_replace_mode (priv->gtr_search_bar, replace);
 }
 
 void
@@ -210,7 +217,7 @@ gtr_tab_find_next (GtrTab * tab)
   GtrTabPrivate *priv;
 
   priv = gtr_tab_get_instance_private (tab);
-  gtr_search_bar_find_next (priv->search_bar);
+  gtr_search_bar_find_next (priv->gtr_search_bar);
 }
 
 void
@@ -219,7 +226,7 @@ gtr_tab_find_prev (GtrTab * tab)
   GtrTabPrivate *priv;
 
   priv = gtr_tab_get_instance_private (tab);
-  gtr_search_bar_find_prev (priv->search_bar);
+  gtr_search_bar_find_prev (priv->gtr_search_bar);
 }
 
 void
@@ -242,7 +249,7 @@ gtr_page_notify_child_revealed (GtrTab *tab,
        * as it can reselect the search text.
        */
       if (focus == NULL || !gtk_widget_is_ancestor (focus, GTK_WIDGET (revealer)))
-        gtk_widget_grab_focus (GTK_WIDGET (priv->search_bar));
+        gtk_widget_grab_focus (GTK_WIDGET (priv->gtr_search_bar));
     }
 }
 
@@ -261,6 +268,76 @@ show_hide_revealer (GtkWidget *widget, GdkEvent *ev, GtrTab *tab)
   return TRUE;
 }
 
+static gboolean
+msg_grab_focus (GtrTab *tab)
+{
+  GtrTabPrivate *priv;
+  priv = gtr_tab_get_instance_private (tab);
+  gtk_widget_grab_focus (priv->trans_msgstr[0]);
+  return FALSE;
+}
+
+static void
+handle_file_is_inconsistent (GtrPo *po, GtrTab *tab)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  GtrProfileManager *manager = gtr_profile_manager_get_default ();
+  GtrProfile *active_profile = gtr_profile_manager_get_active_profile (manager);
+  const char *profile_name = gtr_profile_get_name (active_profile);
+  int profile_nplurals = -1;
+  int po_nplurals = -1;
+
+  g_autofree char *info_msg_primary = NULL;
+  g_autofree char *info_msg_secondary = NULL;
+  g_autofree char *filename = NULL;
+  g_autoptr (GFile) po_file = gtr_po_get_location (po);
+
+  filename = g_file_get_path (po_file);
+  po_nplurals = gtr_header_get_nplurals (gtr_po_get_header (po));
+  profile_nplurals = parse_nplurals_header (gtr_profile_get_plural_forms (active_profile));
+
+  info_msg_primary = g_strdup_printf (_("File is not consistent with profile %s"), profile_name);
+  info_msg_secondary = g_strdup_printf (_(
+    "File nplurals: %d, is different from profile nplurals %d.\n"
+    "Kindly go to preferences and select a profile with consistent nplurals "
+    "values as this file %s."),
+    po_nplurals, profile_nplurals, filename
+  );
+  gtr_tab_set_info (tab, info_msg_primary, info_msg_secondary);
+
+  GtkWidget *nb = priv->trans_notebook;
+  gtk_widget_set_sensitive (nb, FALSE);
+
+  g_object_unref (manager);
+}
+
+static void
+on_active_profile_changed (GtrProfileManager *manager, GtrProfile *profile, GtrTab *tab)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  GtkWidget *nb = priv->trans_notebook;
+
+  GtrPo *po = priv->po;
+  if (!gtr_po_consistent_with_profile (po))
+  {
+    gtr_po_emit_file_not_consistent (po);
+  }
+  else
+  {
+    gtk_widget_set_sensitive (nb, TRUE);
+  }
+}
+
+static void
+on_profile_modified (GtrProfileManager *manager,
+                     GtrProfile *old_profile,
+                     GtrProfile *new_profile,
+                     GtrTab *tab)
+{
+  on_active_profile_changed (manager, new_profile, tab);
+}
+
+
 static void
 install_autosave_timeout (GtrTab * tab)
 {
@@ -333,7 +410,6 @@ static void
 gtr_tab_edition_finished (GtrTab * tab, GtrMsg * msg)
 {
   gchar *message_error;
-  GtkWidget *infobar;
 
   /*
    * Checking message
@@ -342,17 +418,16 @@ gtr_tab_edition_finished (GtrTab * tab, GtrMsg * msg)
 
   if (message_error != NULL)
     {
-      gtr_tab_block_movement (tab);
+      g_autoptr (GtkAlertDialog) dialog = gtk_alert_dialog_new (_("There is an error in the message:"));
 
-      infobar = create_error_info_bar (_("There is an error in the message:"),
-                                       message_error);
-      gtr_tab_set_info_bar (tab, infobar);
+      gtr_tab_block_movement (tab);
+      gtk_alert_dialog_set_detail (GTK_ALERT_DIALOG (dialog), message_error);
+      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), gtr_tab_get_window (tab));
       g_free (message_error);
     }
   else
     {
       gtr_tab_unblock_movement (tab);
-      gtr_tab_set_info_bar (tab, NULL);
     }
 }
 
@@ -450,34 +525,35 @@ gtr_tab_append_msgstr_page (const gchar * tab_label,
 {
   GtkWidget *scroll;
   GtkWidget *label;
-  GtkWidget *widget;
+  GtkWidget *view;
+  GtrHeader *header;
   GtrTabPrivate *priv;
 
-  label = gtk_label_new (tab_label);
-
-  scroll = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_show (scroll);
-
-  widget = gtr_view_new ();
-  gtk_widget_show (widget);
+  g_autofree char *lang_code = NULL;
 
   priv = gtr_tab_get_instance_private (tab);
 
-  if (spellcheck &&
-      g_settings_get_boolean (priv->editor_settings,
-                              GTR_SETTINGS_SPELLCHECK))
-    {
-      gtr_view_enable_spellcheck (GTR_VIEW (widget), spellcheck);
-    }
+  header = gtr_po_get_header (priv->po);
+  lang_code = gtr_header_get_language_code (header);
 
-  gtk_container_add (GTK_CONTAINER (scroll), widget);
+  label = gtk_label_new (tab_label);
 
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-                                       GTK_SHADOW_IN);
+  scroll = gtk_scrolled_window_new ();
+  gtk_widget_set_visible (scroll, TRUE);
+
+  view = gtr_view_new ();
+  gtk_widget_set_visible (view, TRUE);
+
+  //gtk_container_add (GTK_CONTAINER (scroll), view);
+  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scroll), view);
+
+  /*gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
+                                       GTK_SHADOW_IN);*/
 
   gtk_notebook_append_page (GTK_NOTEBOOK (box), scroll, label);
+  gtr_view_set_lang (GTR_VIEW (view), lang_code);
 
-  return widget;
+  return view;
 }
 
 static void
@@ -504,10 +580,10 @@ gtr_message_plural_forms (GtrTab * tab, GtrMsg * msg)
           buf =
             gtk_text_view_get_buffer (GTK_TEXT_VIEW
                                       (priv->trans_msgstr[i]));
-          gtk_source_buffer_begin_not_undoable_action (GTK_SOURCE_BUFFER
-                                                       (buf));
+          //gtk_source_buffer_begin_not_undoable_action (GTK_SOURCE_BUFFER (buf));
+          gtk_text_buffer_begin_irreversible_action (buf);
           gtk_text_buffer_set_text (buf, (gchar *) msgstr_plural, -1);
-          gtk_source_buffer_end_not_undoable_action (GTK_SOURCE_BUFFER (buf));
+          gtk_text_buffer_end_irreversible_action (buf);
         }
     }
 }
@@ -539,23 +615,26 @@ gtr_tab_show_message (GtrTab * tab, GtrMsg * msg)
   if (msgctxt)
    {
      gtk_label_set_text (GTK_LABEL (priv->msgid_ctxt), msgctxt);
-     gtk_widget_show (priv->msgid_ctxt);
+     gtk_widget_set_visible (priv->msgid_ctxt, TRUE);
    }
   else
    {
-     gtk_widget_hide (priv->msgid_ctxt);
+     gtk_widget_set_visible (priv->msgid_ctxt, FALSE);
    }
 
   po = priv->po;
+  if (!po)
+    return;
+
   gtr_po_update_current_message (po, msg);
   msgid = gtr_msg_get_msgid (msg);
   if (msgid)
     {
       gchar *msg_error = gtr_msg_check (msg);
       buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->text_msgid));
-      gtk_source_buffer_begin_not_undoable_action (GTK_SOURCE_BUFFER (buf));
+      gtk_text_buffer_begin_irreversible_action (buf);
       gtk_text_buffer_set_text (buf, (gchar *) msgid, -1);
-      gtk_source_buffer_end_not_undoable_action (GTK_SOURCE_BUFFER (buf));
+      gtk_text_buffer_begin_irreversible_action (buf);
 
       if (gtr_msg_is_fuzzy (msg))
         gtk_label_set_text (GTK_LABEL (priv->msgid_tags), _("fuzzy"));
@@ -571,24 +650,22 @@ gtr_tab_show_message (GtrTab * tab, GtrMsg * msg)
       /*
        * Disable notebook tabs and hide widgets
        */
-      gtk_widget_hide (priv->text_plural_scroll);
+      gtk_widget_set_visible (priv->text_plural_scroll, FALSE);
       gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->trans_notebook), FALSE);
       gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->trans_notebook), 0);
       if (msgstr)
         {
-          buf =
-            gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->trans_msgstr[0]));
-          gtk_source_buffer_begin_not_undoable_action (GTK_SOURCE_BUFFER
-                                                       (buf));
+          buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->trans_msgstr[0]));
+          gtk_text_buffer_begin_irreversible_action (buf);
           gtk_text_buffer_set_text (buf, (gchar *) msgstr, -1);
-          gtk_source_buffer_end_not_undoable_action (GTK_SOURCE_BUFFER (buf));
+          gtk_text_buffer_end_irreversible_action (buf);
           gtk_label_set_mnemonic_widget (GTK_LABEL (priv->msgstr_label),
                                          priv->trans_msgstr[0]);
         }
     }
   else
     {
-      gtk_widget_show (priv->text_plural_scroll);
+      gtk_widget_set_visible (priv->text_plural_scroll, TRUE);
       gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->trans_notebook),
                                   TRUE);
       buf =
@@ -617,6 +694,15 @@ emit_selection_changed (GtkTextBuffer * buf, GParamSpec * spec, GtrTab * tab)
   g_signal_emit (G_OBJECT (tab), signals[SELECTION_CHANGED], 0);
 }
 
+static void
+emit_searchbar_toggled (GtkSearchBar *search_bar,
+                        GParamSpec   *pspec,
+                        GtrTab       *tab)
+{
+  gboolean revealed = gtk_search_bar_get_search_mode (search_bar);
+  g_signal_emit (G_OBJECT (tab), signals[SEARCHBAR_TOGGLED], 0, revealed);
+}
+
 static void
 update_status (GtrTab * tab, GtrMsg * msg, gpointer useless)
 {
@@ -688,7 +774,7 @@ update_status (GtrTab * tab, GtrMsg * msg, gpointer useless)
   else
     gtk_label_set_text (GTK_LABEL (priv->msgid_tags), "");
 
-  /* We need to update the tab state too if is neccessary */
+  /* We need to update the tab state too if is necessary */
   if (po_state != GTR_PO_STATE_MODIFIED)
     gtr_po_set_state (priv->po, GTR_PO_STATE_MODIFIED);
 }
@@ -713,15 +799,12 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
 
   do
     {
-
       label = g_strdup_printf (_("Plural %d"), i);
       priv->trans_msgstr[i] = gtr_tab_append_msgstr_page (label,
                                                           priv->trans_notebook,
                                                           TRUE,
                                                           tab);
 
-      gtr_view_set_language (GTR_VIEW (priv->trans_msgstr[i]), lang_code);
-
       buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->trans_msgstr[i]));
       g_signal_connect (buf, "end-user-action",
                         G_CALLBACK (gtr_message_translation_update), tab);
@@ -753,12 +836,38 @@ on_state_notify (GtrPo      *po,
   g_object_notify (G_OBJECT (tab), "name");
 }
 
+static void
+sort_by_id_cb (GtkWidget *checkbutton, GtrTab* tab)
+{
+  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
+    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_ID);
+}
+
+static void
+sort_by_status_cb (GtkWidget *checkbutton, GtrTab* tab)
+{
+  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
+    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_STATUS);
+}
+
+static void
+sort_by_msgid_cb (GtkWidget *checkbutton, GtrTab* tab)
+{
+  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
+    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_MSGID);
+}
+
+static void
+sort_by_translated_cb (GtkWidget *checkbutton, GtrTab* tab)
+{
+  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
+    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_TRANSLATED);
+}
+
 static void
 gtr_tab_init (GtrTab * tab)
 {
-  GtrTabPrivate *priv;
-
-  priv = gtr_tab_get_instance_private (tab);
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
 
   gtk_widget_init_template (GTK_WIDGET (tab));
 
@@ -769,15 +878,9 @@ gtr_tab_init (GtrTab * tab)
 
   g_signal_connect (tab, "message-changed", G_CALLBACK (update_status), NULL);
 
-  /*Load gsettings for panes */
-  priv->context_position = g_settings_get_int (priv->state_settings,
-                                               GTR_SETTINGS_CONTEXT_PANEL_SIZE);
-
-  priv->content_position = g_settings_get_int (priv->state_settings,
-                                               GTR_SETTINGS_CONTENT_PANEL_SIZE);
-
-  gtk_paned_set_position (priv->hbox, priv->context_position);
-  gtk_paned_set_position (priv->vertical_box, priv->content_position);
+  /*Load gsettings for flap */
+  priv->flap_state = g_settings_get_boolean (priv->state_settings,
+                                             GTR_SETTINGS_FLAP_STATE);
 
   /* Manage auto save data */
   priv->autosave = g_settings_get_boolean (priv->files_settings,
@@ -791,11 +894,29 @@ gtr_tab_init (GtrTab * tab)
 
   priv->find_replace_flag = FALSE;
   priv->progress = gtr_progress_new ();
-  gtk_widget_show (GTK_WIDGET (priv->progress));
+  priv->progress_gesture_click = gtk_gesture_click_new ();
+  gtk_widget_set_visible (GTK_WIDGET (priv->progress), TRUE);
+
+  gtk_widget_add_controller (priv->progress_box,
+                             GTK_EVENT_CONTROLLER (priv->progress_gesture_click));
   gtk_box_append (GTK_BOX (priv->progress_box), GTK_WIDGET (priv->progress));
 
-  g_signal_connect (priv->progress_eventbox, "button-press-event",
+  g_signal_connect (priv->progress_gesture_click, "pressed",
                     G_CALLBACK (show_hide_revealer), tab);
+
+  g_signal_connect (priv->search_bar, "notify::search-mode-enabled",
+                    G_CALLBACK (emit_searchbar_toggled), tab);
+
+  // TODO: related to header of gtr tab move to saperate header file
+  g_signal_connect (priv->sort_id, "toggled",
+                    G_CALLBACK(sort_by_id_cb), tab);
+  g_signal_connect (priv->sort_status, "toggled",
+                    G_CALLBACK(sort_by_status_cb), tab);
+  g_signal_connect (priv->sort_msgid, "toggled",
+                    G_CALLBACK(sort_by_msgid_cb), tab);
+  g_signal_connect (priv->sort_translated, "toggled",
+                    G_CALLBACK(sort_by_translated_cb), tab);
+  gtk_check_button_set_active (GTK_CHECK_BUTTON (priv->sort_id), TRUE);
 }
 
 static void
@@ -822,14 +943,10 @@ save_pane_state(GtrTab *tab)
 
   priv = gtr_tab_get_instance_private (tab);
 
-  priv->context_position = gtk_paned_get_position (priv->hbox);
-  priv->content_position = gtk_paned_get_position (priv->vertical_box);
+  priv->flap_state = adw_flap_get_folded (priv->hbox);
 
-  g_settings_set_int (priv->state_settings, GTR_SETTINGS_CONTEXT_PANEL_SIZE,
-                      priv->context_position);
-
-  g_settings_set_int (priv->state_settings, GTR_SETTINGS_CONTENT_PANEL_SIZE,
-                      priv->content_position);
+  g_settings_set_boolean (priv->state_settings, GTR_SETTINGS_FLAP_STATE,
+                          priv->flap_state);
 }
 
 static void
@@ -952,6 +1069,15 @@ gtr_tab_class_init (GtrTabClass * klass)
                   g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 
+  signals[SEARCHBAR_TOGGLED] =
+    g_signal_new ("searchbar-toggled",
+                  G_OBJECT_CLASS_TYPE (klass),
+                  G_SIGNAL_RUN_LAST,
+                  G_STRUCT_OFFSET (GtrTabClass, searchbar_toggled),
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__BOOLEAN,
+                  G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+
   /* Properties */
   g_object_class_install_property (object_class,
                                    PROP_NAME,
@@ -995,18 +1121,28 @@ gtr_tab_class_init (GtrTabClass * klass)
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, trans_notebook);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, context);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, hbox);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, vertical_box);
 
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_eventbox);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_box);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_revealer);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_trans);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_fuzzy);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_untrans);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_percentage);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, overlay);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, search_bar);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, search_revealer);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, gtr_search_bar);
+
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, titlebar);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_id);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_status);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_msgid);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_translated);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, order_menu_popover);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, search_toggle);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, undo);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, redo);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, save);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, upload);
+
   gtk_widget_class_bind_template_callback (widget_class, gtr_page_notify_child_revealed);
   gtk_widget_class_bind_template_callback (widget_class, gtr_page_stop_search);
 
@@ -1018,6 +1154,67 @@ gtr_tab_class_init (GtrTabClass * klass)
 
 /***************************** Public funcs ***********************************/
 
+void
+gtr_tab_hide_sort_menu (GtrTab *tab)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+
+  if (priv->sort_id)
+    gtk_popover_popdown (GTK_POPOVER (priv->order_menu_popover));
+}
+
+void
+gtr_tab_enable_find_button (GtrTab *tab,
+                                 gboolean enable)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+
+  if (priv->search_toggle)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->search_toggle), enable);
+}
+
+void
+gtr_tab_enable_save (GtrTab *tab,
+                          gboolean enable)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  gtk_widget_set_sensitive (priv->save, enable);
+}
+
+void
+gtr_tab_update_undo_buttons (GtrTab *tab,
+                                  GtrView  *view)
+{
+  GtkSourceBuffer *active_document;
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  gboolean can_undo, can_redo;
+  g_return_if_fail (view);
+
+  active_document =
+    GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
+  g_return_if_fail(active_document);
+
+  can_undo = gtk_text_buffer_get_can_undo (GTK_TEXT_BUFFER(active_document));
+  can_redo = gtk_text_buffer_get_can_redo (GTK_TEXT_BUFFER(active_document));
+
+  gtk_widget_set_sensitive (priv->undo, can_undo);
+  gtk_widget_set_sensitive (priv->redo, can_redo);
+}
+
+void
+gtr_tab_enable_upload (GtrTab *tab, gboolean enable)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  gtk_widget_set_sensitive (priv->upload, enable);
+}
+
+GtkWidget *
+gtr_tab_get_header (GtrTab *tab)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  return priv->titlebar;
+}
+
 /**
  * gtr_tab_new:
  * @po: a #GtrPo
@@ -1033,15 +1230,19 @@ gtr_tab_new (GtrPo * po,
 {
   GtrTab *tab;
   GtrTabPrivate *priv;
+  GtrProfileManager *manager;
 
   g_return_val_if_fail (po != NULL, NULL);
 
+  manager = gtr_profile_manager_get_default();
+
   tab = g_object_new (GTR_TYPE_TAB, NULL);
 
   priv = gtr_tab_get_instance_private (tab);
   gtr_context_init_tm (GTR_CONTEXT_PANEL (priv->context),
                        gtr_window_get_tm (GTR_WINDOW (window)));
 
+  priv->window = GTK_WIDGET (window);
   /* FIXME: make the po a property */
   priv->po = po;
   g_object_set_data (G_OBJECT (po), GTR_TAB_KEY, tab);
@@ -1052,6 +1253,15 @@ gtr_tab_new (GtrPo * po,
   g_signal_connect (po, "notify::state",
                     G_CALLBACK (on_state_notify), tab);
 
+  g_signal_connect (po, "file-is-inconsistent-with-profile",
+                    G_CALLBACK (handle_file_is_inconsistent), tab);
+
+  g_signal_connect (manager, "active-profile-changed",
+                    G_CALLBACK (on_active_profile_changed), tab);
+
+    g_signal_connect (manager, "profile-modified",
+                    G_CALLBACK (on_profile_modified), tab);
+
   install_autosave_timeout_if_needed (tab);
 
   /* Now we have to initialize the number of msgstr tabs */
@@ -1060,7 +1270,12 @@ gtr_tab_new (GtrPo * po,
   gtr_message_table_populate (GTR_MESSAGE_TABLE (priv->message_table),
                               GTR_MESSAGE_CONTAINER (priv->po));
 
-  gtk_widget_show (GTK_WIDGET (tab));
+  if (!gtr_po_consistent_with_profile (po))
+  {
+    gtr_po_emit_file_not_consistent (po);
+  }
+
+  gtk_widget_set_visible (GTK_WIDGET (tab), TRUE);
   return tab;
 }
 
@@ -1182,15 +1397,12 @@ gtr_tab_get_all_views (GtrTab * tab, gboolean original, gboolean translated)
 **/
 void
 gtr_tab_message_go_to (GtrTab * tab,
-                       GtrMsg * to_go, gboolean searching, GtrTabMove move)
+                       GtrMsg * to_go,
+                       gboolean searching,
+                       GtrTabMove move)
 {
   static gboolean first_msg = TRUE;
-  GtrTabPrivate *priv;
-
-  g_return_if_fail (tab != NULL);
-  g_return_if_fail (GTR_IS_MSG (to_go));
-
-  priv = gtr_tab_get_instance_private (tab);
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
 
   if (!priv->blocking || first_msg)
     {
@@ -1254,8 +1466,18 @@ gtr_tab_message_go_to (GtrTab * tab,
    * Emitting showed-message signal
    */
   if (!searching)
-    g_signal_emit (G_OBJECT (tab), signals[SHOWED_MESSAGE], 0,
-                   GTR_MSG (to_go));
+    {
+      gtr_message_table_select (GTR_MESSAGE_TABLE (priv->message_table), GTR_MSG (to_go));
+
+      g_signal_emit (G_OBJECT (tab), signals[SHOWED_MESSAGE], 0,
+                     GTR_MSG (to_go));
+
+
+      // Grabbing the focus in the GtrView to edit the message
+      // This is done in the idle add to avoid the focus grab from the
+      // message-table
+      g_idle_add ((GSourceFunc)msg_grab_focus, tab);
+    }
 }
 
 /**
@@ -1896,39 +2118,6 @@ gtr_tab_go_to_number (GtrTab * tab, gint number)
     }
 }
 
-/**
- * gtr_tab_set_info_bar:
- * @tab: a #GtrTab
- * @infobar: a #GtrMessageArea
- *
- * Sets the @infobar to be shown in the @tab.
- */
-void
-gtr_tab_set_info_bar (GtrTab * tab, GtkWidget * infobar)
-{
-  GtrTabPrivate *priv;
-
-  g_return_if_fail (GTR_IS_TAB (tab));
-
-  priv = gtr_tab_get_instance_private (tab);
-
-  if (priv->infobar == infobar)
-    return;
-
-  if (priv->infobar != NULL)
-    gtk_widget_destroy (priv->infobar);
-
-  priv->infobar = infobar;
-
-  if (infobar == NULL)
-    return;
-
-  gtk_box_append (GTK_BOX (tab), priv->infobar);
-
-  g_object_add_weak_pointer (G_OBJECT (priv->infobar),
-                             (gpointer *) & priv->infobar);
-}
-
 /**
  * gtr_tab_set_info:
  * @tab: a #GtrTab
@@ -1941,9 +2130,7 @@ gtr_tab_set_info (GtrTab * tab,
                   const char * primary,
                   const char * secondary)
 {
-  GtkWidget *infobar;
-  infobar = create_info_info_bar (primary, secondary);
-  gtr_tab_set_info_bar (tab, infobar);
+  create_info_info_bar (primary, secondary, tab);
 }
 
 GtrMsg *
@@ -2005,3 +2192,10 @@ gtr_tab_find_replace (GtrTab *tab,
   priv->find_replace_flag = set;
 }
 
+GtkWindow *
+gtr_tab_get_window (GtrTab *tab)
+{
+  GtrTabPrivate *priv;
+  priv = gtr_tab_get_instance_private (tab);
+  return GTK_WINDOW (priv->window);
+}
